@@ -4,7 +4,7 @@ from .config import R, config
 
 cat = AyakaCat(f"{R.犯人}在跳舞")
 cat.help = f'''
-3-8人游玩，游玩前请先加bot好友，否则无法发牌。{config.overtime}s内不出牌会被系统强制弃牌（防止挂机）
+3-8人游玩，游玩前请先加bot的qq好友，否则无法发牌。{config.overtime}s内不出牌会被系统强制弃牌（防止挂机）
 '''
 
 help_dict = {
@@ -40,12 +40,11 @@ async def _():
     await cat.send(help)
 
 total_helps = f'''
-开局每人4张手牌，轮流出牌
-拥有{R.第一发现人}的人优先出牌（类似扑克规则的红桃3），且第一张牌必须是{R.第一发现人}
+开局每人4张手牌，轮流出牌，整局游戏的第一张牌必须是{R.第一发现人}（类似扑克规则中的红桃3）
 
-{R.犯人}牌只有在手牌数为1的时候才能打出，此时打出者作为{R.犯人}而胜利
+游戏分为好人阵营和坏人阵营，默认都是好人，而最终打出{R.犯人}牌的人作为坏人而胜利
+但{R.犯人}牌只有在手牌数为1的时候才能打出，此时打出者作为{R.犯人}而胜利
 其他人的目标就是在{R.犯人}逃跑成功之前，通过{R.侦探}、{R.神犬}、{R.警部}等牌抓到{R.犯人}，此时好人阵营胜利
-
 当你打出{R.共犯}牌后，你便加入了坏人阵营，需要协助{R.犯人}获胜
 当然，你也可以当个二五仔，若{R.共犯}使用{R.侦探}等牌抓到了{R.犯人}，那么他也视为好人阵营一同胜利
 
